@@ -1,10 +1,10 @@
-/* $Cambridge: exim/exim-src/exim_monitor/em_globals.c,v 1.11 2007/01/08 10:50:17 ph10 Exp $ */
+/* $Cambridge: exim/src/exim_monitor/em_globals.c,v 1.17 2009/11/16 19:50:36 nm4 Exp $ */
 
 /*************************************************
 *                Exim Monitor                    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2007 */
+/* Copyright (c) University of Cambridge 1995 - 2009 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 
@@ -135,10 +135,14 @@ BOOL    deliver_freeze         = FALSE;
 int     deliver_frozen_at      = 0;
 BOOL    deliver_manual_thaw    = FALSE;
 
-#ifdef EXPERIMENTAL_DOMAINKEYS
-uschar *dk_signing_domain      = NULL;
-uschar *dk_signing_selector    = NULL;
-int     dk_do_verify           = 0;
+#ifndef DISABLE_DKIM
+uschar *dkim_cur_signer          = NULL;
+uschar *dkim_signers             = NULL;
+uschar *dkim_signing_domain      = NULL;
+uschar *dkim_signing_selector    = NULL;
+uschar *dkim_verify_signers      = US"$dkim_signers";
+BOOL    dkim_collect_input       = FALSE;
+BOOL    dkim_disable_verify      = FALSE;
 #endif
 
 BOOL    dont_deliver           = FALSE;
@@ -160,9 +164,13 @@ uschar *local_scan_data        = NULL;
 BOOL    log_timezone           = FALSE;
 
 #ifdef WITH_CONTENT_SCAN
+uschar *spam_bar               = NULL;
+uschar *spam_report            = NULL;
+uschar *spam_score             = NULL;
 uschar *spam_score_int         = NULL;
 #endif
 
+int     max_received_linelength= 0;
 int     message_age            = 0;
 uschar *message_id;
 uschar *message_id_external;
